Stan Math Library: stan/math/rev/scal/fun/sinh.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

sinh.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_SINH_HPP
2 #define STAN_MATH_REV_SCAL_FUN_SINH_HPP
3
4 #include <stan/math/rev/core.hpp>
5 #include <valarray>
6
7 namespace stan {
8 namespace math {
9
10 namespace {
11 class sinh_vari : public op_v_vari {
12 public:
13 explicit sinh_vari(vari* avi) :
14 op_v_vari(std::sinh(avi->val_), avi) {
15 }
16 void chain() {
17 avi_->adj_ += adj_ * std::cosh(avi_->val_);
18 }
19 };
20 }
21
49 inline var sinh(const var& a) {
50 return var(new sinh_vari(a.vi_));
51 }
52
53 }
54 }
55 #endif
core.hpp
stan::math::cosh
fvar< T > cosh(const fvar< T > &x)
Definition: cosh.hpp:13
stan
Definition: log_sum_exp.hpp:8
std
Definition: std_numeric_limits.hpp:7
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::var::vi_
vari * vi_
Pointer to the implementation of this variable.
Definition: var.hpp:43
stan::math::sinh
fvar< T > sinh(const fvar< T > &x)
Definition: sinh.hpp:14

[ Stan Home Page ] © 2011–2016, Stan Development Team.